# Changelog
All notable changes to this project are documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.5.5]
### Changed
- Update `deploy aws` to retry getting the IP address of the new EC2 instance.
- Update `deploy aws` to remove the dependancy on the `ssh` client being installed.
- Update `deploy aws` to remove the dependancy on the `scp` client being installed.

## [0.5.4]
### Changed
- Update `deploy aws` command to provide the platform 'basic'.
- Update `undeploy aws` command to delete AWS Cloudwatch Log Group.

## [0.5.3]
### Changed
- Update `deploy aws` command to detect when EC2 VPC is not available.
- Update `deploy aws` command to allow the user to specify the Subnet Id.

## [0.5.2]
### Changed
- Update `deploy aws` command by adding IdentitiesOnly option to SSH login commands.
- Update `deploy aws` command to pick latest available AMI.
- Update `deploy aws` command to retry SSH logins to new EC2 instance up to 20 times.
### Added
- Add the `log` command to display real-time logs.
- Add AWS MQTT Proxy deployment to `deploy aws` command.

## [0.5.1]
### Changed
- Tool now logins into http://production.uniquid.co by default.

## [0.5.0]
### Added
- Log file generated by all commands and stored to local filesystem.
- Permissions of credentials file updated if they are too broad.
- Add `undeploy aws` command to remove AWS resources created by `deploy aws`.
### Changed
- Numerous small fixes to `deploy aws` command.
- Disable commands on Windows machines: `deploy`, `list-shares`, `create-shares`, `delete-shares`.
- Update `deploy aws` command so that AWS EC2 Key Pair filename has matching timestamp.
- Update `deploy aws` command so that the IAM Role includes the timestamp it is name.
- Improve how `deploy aws` command handles the creation of AWS EC2 Security Groups.
- Add `--yes` option to `deploy` and `undeploy` commands.
- Update output from `status` command. Now differentiates between configured and connected.

## [0.4.9]
### Changed
- Fix incorrect name give to AWS Security Group by `deploy aws` command.

## [0.4.8]
### Changed
- Update `deploy aws` command to add timestamp to names of IoT Authorizer, Agent and Lambda function.
- Fix `deploy aws` command to download AWS agent tarball from IP address passed in with --login-url option.

## [0.4.7]
### Changed
- Update IP address of login server to Blue production server.

## [0.4.6]
### Changed
- Update network type parameter for Litecoin RegTest.

## [0.4.5]
### Changed
- Improvements to `deploy aws` command.  Add retries when executing shell commands.
- Update network type parameter values expected from the orchestrator HTTP API.

## [0.4.4]
### Changed
- User Guide updates.
- Add work-around to `deploy aws` for issue with Orchestrator HTTP API.

## [0.4.3]
### Changed
- Fixes to `deploy aws`.

## [0.4.2]
### Changed
- Fixes to `deploy aws`.

## [0.4.1]
### Changed
- Fixes to `deploy aws`.

## [0.4.0]
### Added
- Added the `deploy aws` command.

## [0.3.0]
### Changed
- Fixes for product demo.

## [0.2.0]
### Added
- Added the `--credentials-file` option to the `login` command.

## [0.1.1] - 2018-08-31
### Changed
- No functional changes. Packaging change for [PyPi](https://pypi.org/).

## [0.1.0] - 2018-08-31
### Added
- Initial version of the CLI tool published to [PyPi](https://pypi.org/).
